# Changelog

## [0.1.1] - 2019-05-20
 - Fixes bugs with color not using alpha channel (#45)
 - Created checks for unsupported symbol layer and simplified layer class
   selection logic (#46)
 - Removed incorrect visibility logic from layer converter (#51)

## [0.1.0] - 2019-05-02
 - Initial release
